package com.stormtales.notevault.ui.login;

import android.app.AlertDialog;
import android.app.Dialog;
import android.content.Context;
import android.os.Bundle;
import android.util.Log;
import android.view.LayoutInflater;
import android.view.View;
import android.widget.Button;
import android.widget.EditText;
import android.widget.TextView;
import androidx.annotation.NonNull;
import androidx.annotation.Nullable;
import androidx.fragment.app.DialogFragment;
import com.stormtales.notevault.R;
import com.stormtales.notevault.network.APICallback;
import com.stormtales.notevault.network.auth.AuthService;

public class LoginDialog extends DialogFragment {

    private APICallback loginCallback;
    private APICallback registerCallback;

    private boolean isLoginMode = true;

    private Dialog dialog;

    @Override
    public void onAttach(Context context) {
        super.onAttach(context);
        if (loginCallback == null) {
            throw new IllegalStateException("LoginDialogFragment must be created using newInstance()");
        }
    }

    public static LoginDialog newInstance(APICallback loginCallback, APICallback registerCallback) {
        LoginDialog fragment = new LoginDialog();
        fragment.loginCallback = loginCallback;
        fragment.registerCallback = registerCallback;
        return fragment;
    }

    @NonNull
    @Override
    public Dialog onCreateDialog(@Nullable Bundle savedInstanceState) {
        AlertDialog.Builder builder = new AlertDialog.Builder(requireContext());
        LayoutInflater inflater = requireActivity().getLayoutInflater();
        View view = inflater.inflate(R.layout.fragment_login_dialog, null);

        TextView textViewTitle = view.findViewById(R.id.textViewTitle);
        EditText editTextUsername = view.findViewById(R.id.editTextUsername);
        EditText editTextEmail = view.findViewById(R.id.editTextEmail);
        EditText editTextPassword = view.findViewById(R.id.editTextPassword);
        Button buttonAction = view.findViewById(R.id.buttonAction);
        TextView textViewSwitch = view.findViewById(R.id.textViewSwitch);

        // Handle action button click
        buttonAction.setOnClickListener(v -> {
            if (isLoginMode) {
                // Handle login logic
                String email = editTextEmail.getText().toString();
                String password = editTextPassword.getText().toString();
                AuthService authRepository = new AuthService(this.getContext());
                authRepository.performLogin(email, password, loginCallback);
            } else {
                // Handle registration logic
                String email = editTextEmail.getText().toString();
                String password = editTextPassword.getText().toString();
                String username = editTextUsername.getText().toString();
                AuthService authRepository = new AuthService(this.getContext());
                authRepository.performRegistration(email, username, password, registerCallback);
            }
        });

        // Toggle between Login and Registration
        textViewSwitch.setOnClickListener(v -> {
            isLoginMode = !isLoginMode;
            textViewTitle.setText(isLoginMode ? "Login" : "Register");
            editTextUsername.setVisibility(isLoginMode ? View.GONE : View.VISIBLE);
            buttonAction.setText(isLoginMode ? "Login" : "Register");
            textViewSwitch.setText(isLoginMode ? "Don't have an account? Register" : "Already have an account? Login");
        });

        builder.setView(view);
        return builder.create();
    }

}
